# example analysis script for a set of e/m data
# analysis of e/m data

import LT.box as BB

# electron mass
me = 9.11e-31

# elementqry charge
ec = 1.6e-19

em_th = ec/me  # theoretical value of e/m

# get pi
pi = BB.np.pi

# get the file
mf = BB.get_file('em_150V.data')

# convert cm to m
m = 0.01

# get the data

# the voltage used for these data
V = 150.

I = BB.get_data(mf, 'I')
r = BB.get_data(mf, 'R')*m   # convert cm to m
dr = BB.get_data(mf, 'dR')*m

# Magnetic field parameters
N = 132.   # number of turns
Rc = 0.15  # radius of coil
mu0 = 4.*pi* 1.e-7

# calculation of B
B = mu0*N*I/Rc*(4./5.)**1.5

Bi2 = B**(-2)
r2 = r**2
dr2 = 2.*r*dr

# plot data
BB.plot_exp(Bi2, r2, dr2)
BB.pl.xlabel('1./B**2 (T^-2)')
BB.pl.ylabel('r**2 (m^2)' )
BB.pl.title('e/m ratio analysis V = 150V')

# do the fit
fit = BB.linefit(Bi2, r2, dr2)
BB.plot_line(fit.xpl, fit.ypl) # plot the fit
BB.pl.show()

# calculate e/m ratio
em = 2.*V/fit.slope

# error in em (using error propagation)

d_em = 2.*V * (1./fit.slope**2) * fit.sigma_s

# print the result
print('----------------- final results -----------------------')
print('error due to I and V measurement not included !')
print(' ')
print('e/m           = ', em, '  +/- ', d_em, ' = ',  d_em/em*100, '%')
print('e/m published = ', em_th)
print('deviation     = ', (em-em_th)/em_th*100. , ' %')
print('-------------------------------------------------------')

# for nicer format check out the python documentation
